<template>
    <div class="app-container">
        <div class="filter-container">
            <div style="display: block;">
                <div class="basic_search" style="padding-top: 10px;">
                    <span>按时间查询：</span>
                    <el-date-picker
                        value-format="yyyy-MM-dd HH:mm:ss"
                        v-model="validTime"
                        type="daterange"
                        :default-time="['00:00:00','23:59:59']"
                        range-separator="-"
                        start-placeholder="开始日期"
                        end-placeholder="结束日期"
                    >
                    </el-date-picker>
                </div>
                <div class="basic_search" style="margin-right: 10px;padding-top: 10px">
                    <span>推送状态：</span>
                    <el-select v-model="listQuery.filter.pushType" clearable filterable>
                        <el-option key="0" label="未下发" :value="0"></el-option>
                        <el-option key="1" label="已下发" :value="1"></el-option>
                        <el-option key="2" label="已反馈" :value="2"></el-option>
                    </el-select>
                </div>
                <div class="basic_search">
                    <span>区域：</span>
                    <el-select v-model="listQuery.filter.provinceCode" clearable filterable @change="changeArea('province')">
                        <el-option
                            v-for="item in provinceList"
                            :key="item.id"
                            :label="item.name"
                            :value="item.code"
                        >
                        </el-option>
                    </el-select>
                </div>
                <div class="basic_search">
                    <el-select v-model="listQuery.filter.cityCode" prop="city" clearable filterable @change="changeArea('city')">
                        <el-option
                            v-for="item in cityList"
                            :key="item.id"
                            :label="item.name"
                            :value="item.code"
                        >
                        </el-option>
                    </el-select>
                </div>
                <div class="basic_search">
                    <el-select v-model="listQuery.filter.areaCode" clearable filterable>
                        <el-option
                            v-for="item in districtList"
                            :key="item.id"
                            :label="item.name"
                            :value="item.code"
                        >
                        </el-option>
                    </el-select>
                </div>
                <div class="basic_search" style="margin-right: 10px;padding-top: 10px">
                    <span>企业名称：</span>
                    <el-input v-model.trim="listQuery.filter.companyName" style="width: 300px"/>
                </div>
                <div class="basic_search" style="margin-right: 10px">
                    <el-button style="margin-left: 10px;" type="primary" @click="reset()">重置</el-button>
                    <el-button style="margin-left: 10px;" type="primary" icon="el-icon-search" @click="search()">查询</el-button>
                </div>
            </div>
        </div>
        <div class="table_content">
            <el-table
                v-loading="listLoading"
                :key="tableKey"
                :data="dataList"
                border
                fit
                highlight-current-row
                style="width: 100%;"
            >
                <el-table-column label="序号" type="index" align="center"></el-table-column>
                <el-table-column label="企业名称" prop="companyName" align="center"></el-table-column>
                <el-table-column label="市（地、州）" prop=cityName"" align="center"></el-table-column>
                <el-table-column label="区县" prop="areaName" align="center"></el-table-column>
                <el-table-column label="风险等级" prop="riskLevel" align="center"></el-table-column>
                <el-table-column label="推送状态" prop="pushType" align="center">
                    <template slot-scope="scope">
                        {{ scope.row.pushType == 0?'未下发':scope.row.pushType == 1?'已下发':'已反馈' }}
                    </template>
                </el-table-column>
                <el-table-column label="推送内容" prop="pushContent" align="center"></el-table-column>
                <el-table-column label="反馈意见" prop="feedback" align="center"></el-table-column>
                <el-table-column label="创建时间" prop="createDate" align="center"></el-table-column>
                <el-table-column label="创建人" prop="createBy" align="center"></el-table-column>
                <el-table-column label="更新时间" prop="updateDate" align="center"></el-table-column>
                <el-table-column label="更新人" prop="updateBy" align="center"></el-table-column>
<!--                <el-table-column label="操作" align="center" width="120" class-name="small-padding fixed-width" fixed="right">-->
<!--                    <template slot-scope="scope">-->
<!--                        <el-button type="text" @click="handleBack(scope.row)">提交反馈</el-button>-->
<!--                        <el-button type="text" @click="deleteData(scope.row)">标记删除</el-button>-->
<!--                    </template>-->
<!--                </el-table-column>-->
            </el-table>
            <br>
            <div style="display: flex;justify-content: right">
                <el-pagination
                    v-show="recordTotal>0"
                    :current-page="currentPage"
                    :page-sizes="[10, 20, 30, 50]"
                    :page-size="listQuery.pageSize"
                    :total="recordTotal"
                    layout="total, sizes, prev, pager, next, jumper"
                    background
                    @size-change="handleSizeChange"
                    @current-change="handleCurrentChange"
                />
            </div>
            <pre-warning-dialog ref="preWarningRef"></pre-warning-dialog>
        </div>
    </div>
</template>

<script>
import {computePageCount} from "../../../utils";
import {regionPifaBox} from "../../../api/stock"
import preWarningDialog from "./components/preWarningDialog"
import {getCityListData, getProvinceListData} from "../../../api/area";
import {getEarlyPush, getOriginalAlarm} from "../../../api/monitorAlert";

export default {
    name: "preWarning",
    components: { preWarningDialog },
    data() {
        return {
            tableKey: '',
            recordTotal: 0,
            currentPage: 1,
            validTime: [],
            areaListQuery: {},
            provinceList: [],
            cityList: [],
            districtList: [],
            listLoading: false,
            dataList: [],
            listQuery: {
                filter:{
                    createDateStart: '',
                    createDateEnd: '',
                    pushType: null,
                    companyCode: '',
                    companyName: '',
                    provinceCode: '',
                    cityCode: '',
                    areaCode: ''
                },
                pageIndex:1,
                pageSize:10
            },
        }
    },
    created() {
        this.getProvince()
        this.getDataList()
    },
    mounted() {
    },
    watch: {},
    methods: {
        openDialog(type,data){
            this.$refs.preWarningRef.open(type,data)
        },
        handleBack(){

        },
        deleteData(data){

        },
        async getProvince(){
            let res = await getProvinceListData()
            if(res.data.code === "200"){
                this.provinceList = res.data.result.provinceList
            }
        },//获取省
        async changeArea(value){
            if(value === 'province'){
                this.listQuery.filter.cityCode = ''
                this.listQuery.filter.areaCode = ''
                this.areaListQuery = {
                    type: 2,
                    parenttype: 1,
                    parentname: this.provinceList.find(i=>i.code == this.listQuery.filter.provinceCode).name
                }
                let res = await getCityListData(this.areaListQuery)
                if(res.data.code === "200"){
                    this.cityList = res.data.result
                }
            }else{
                this.listQuery.filter.areaCode = ''
                this.areaListQuery = {
                    type: 3,
                    parenttype: 2,
                    parentname:this.cityList.find(i=>i.code == this.listQuery.filter.cityCode).name
                }
                let res = await getCityListData(this.areaListQuery)
                if(res.data.code === "200"){
                    this.districtList = res.data.result
                }
            }
        },//市、镇、街道、委员会
        async getDataList() {
            if(this.validTime.length>0){
                this.listQuery.filter.createDateStart = this.validTime[0]
                this.listQuery.filter.createDateEnd = this.validTime[1]
            }
            let res = await getEarlyPush(this.listQuery)
            if (res.data.code === "200") {
                const data = res.data.result
                if(Array.isArray(data.records)){
                    this.dataList = data.records
                    this.recordTotal = data.total
                    this.currentPage = data.current
                }else{
                    this.dataList = []
                }
            } else {
                this.$message({
                    type: 'warning',
                    message: res.data.message
                })
            }
            this.listLoading = false
        },
        handleSizeChange: function(val) {
            this.listQuery.pageSize = val
            this.getDataList()
        },
        handleCurrentChange: function(val) {
            this.listQuery.pageIndex = val
            this.getDataList()
        },
        reset(){
            this.listQuery = {
                filter:{
                    createDateStart: '',
                    createDateEnd: '',
                    pushType: null,
                    companyCode: '',
                    companyName: '',
                    provinceCode: '',
                    cityCode: '',
                    areaCode: ''
                },
                pageIndex:1,
                pageSize:10
            }
            this.validTime = []
            this.cityList= []
            this.districtList= []
            this.getDataList()
        },
        search(){
            this.listQuery.pageIndex = 1
            this.getDataList()
        }
    },
}
</script>

<style scoped>
.basic_search {
    display: inline-block;
}
</style>
